1. make_reference_structure.py

2. get_IC_md.py

3. learn_im_parameters.py

4. make_im_system.py

5. run_im_NVT_sampling.py

6. plot_bad_hist_im.py

7. compute_rmsd_centers_and_k_for_imus.py   

8. run_im_umbrella_sampling.py via submit_im_umbrella_sampling.sh

9. plot_rmsd_imus.py

10. compute_log_q_imus.py   
   
11. compute_basis_for_angles_and_dihedrals.py

12. contrastive_learning.py via submit_contrastive_learning.sh

13. make_full_system.py
